@@ -24,6 +24,5 @@
 #define speedy_bzero(s,n)	Zero(s,n,char)
 #define speedy_free(s)		Safefree(s)
 #define speedy_execvp(f,a)	execvp(f,(char * const*)a)
-
-SPEEDY_INLINE void *speedy_malloc(size_t size);
-SPEEDY_INLINE void *speedy_realloc(void *ptr, size_t size);
+#define speedy_new(s,n,t)	New(123,s,n,t)
+#define speedy_renew(s,n,t)	Renew(s,n,t)
