@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000  Daemon Consulting Inc.
+ * Copyright (C) 2001  Daemon Consulting Inc.
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,15 +24,19 @@ typedef struct _CopyBuf {
     int  eof;
     int  rdfd;
     int  wrfd;
+    int	 write_err;
 } CopyBuf;
 
-#define CANREAD(buf)	((buf).sz < (buf).maxsz && (buf).eof == 0)
-#define CANWRITE(buf)	((buf).sz > 0)
-#define COPYDONE(buf)	((buf).eof != 0 && (buf).sz == 0)
-#define BUF_FULL(buf)	((buf).sz == (buf).maxsz)
-#define BUF_SZ(buf)	((buf).sz)
-#define BUF_EOF(buf)	((buf).eof)
-#define BUF_SETEOF(buf)	(buf).eof = 1
+#define CANREAD(buf)  ((buf).sz < (buf).maxsz && !(buf).eof && !(buf).write_err)
+#define CANWRITE(buf) ((buf).sz > 0)
+#define COPYDONE(buf) (((buf).eof != 0 && (buf).sz == 0) || (buf).write_err)
+
+#define BUF_FULL(buf)			((buf).sz == (buf).maxsz)
+#define BUF_SZ(buf)			((buf).sz)
+#define BUF_EOF(buf)			((buf).eof)
+#define BUF_SETEOF(buf)			(buf).eof = 1
+#define BUF_SET_WRITE_ERR(buf,e)	(buf).write_err = (e)
+#define BUF_GET_WRITE_ERR(buf)		((buf).write_err)
 
 void speedy_cb_alloc(
     CopyBuf *bp, int maxsz, int rdfd, int wrfd, char *buf, int sz
@@ -40,3 +44,4 @@ void speedy_cb_alloc(
 void speedy_cb_free(CopyBuf *bp);
 void speedy_cb_read(CopyBuf *bp);
 void speedy_cb_write(CopyBuf *bp);
+int speedy_cb_shift(CopyBuf *bp);
